
package com.dskj.znzn.transData.web.waveData.controller;

import com.dskj.znzn.transData.common.base.PageR;
import com.dskj.znzn.transData.common.base.R;
import com.dskj.znzn.transData.web.waveData.entity.WaveData;
import com.dskj.znzn.transData.web.waveData.indata.GetMesureDataInData;
import com.dskj.znzn.transData.web.waveData.indata.GetMesureWithSFDataInData;
import com.dskj.znzn.transData.web.waveData.service.IWaveDataService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping({"/waveData"})
@Api(tags = {"振动数据接口"})
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
public class WaveDataController {
    private final IWaveDataService waveDataService;

    @PostMapping({"getMesureData"})
    @ApiOperation("获取测点数据")
    public R<List<WaveData>> getMesureData(@RequestBody @Valid GetMesureDataInData inData) {
        return R.ok(this.waveDataService.getMesureData(inData));
    }

    @PostMapping({"getMesureDataWithSF"})
    @ApiOperation("获取测点数据-添加采样频率")
    public PageR<WaveData> getMesureDataWithSF(@RequestBody @Valid GetMesureWithSFDataInData inData) {
        return this.waveDataService.getMesureDataWithSF(inData);
    }


    @GetMapping({"/{windCode}/{id}"})
    @ApiOperation("根据ID获取测点数据")
    public R<WaveData> getById(@PathVariable String windCode, @PathVariable Integer id) {
        return R.ok(this.waveDataService.getById(windCode, id));
    }

    @GetMapping("/getAllSamplingFrequency/{windCode}")
    @ApiOperation("获取风场所有采样频率")
    public R<List<String>> getAllSamplingFrequency(@PathVariable String windCode) {
        return R.ok(waveDataService.getAllSamplingFrequency(windCode));
    }
}
